@echo off
REM Script used to debug sub-processes launched via sys.executable
REM as is done by multiprocessing on Windows and in other cases
REM We replace sys.executable with this script, which inserts code
REM that starts debugging before the users's module is invoked.

REM The command line contains the file name to debug and its arguments

REM The debugger is configured using the following envs:

REM WINGDB_PYTHON   -- The Python to use for debugging (default=python)
REM WINGDB_HOSTPORT -- The hostname:port to connect to (default=localhost:50005)
REM WINGDB_PYARGS   -- Any arguments to pass to Python.  Defaults to -u.  
REM                    Set this to '-' to not pass any arguments.

REM See the manual for other supported WINGDB_* environment variables.

REM Make variables surrounded by !! work like any sane human would expect
SETLOCAL ENABLEDELAYEDEXPANSION

REM Set up WINGHOME
if "%WINGHOME%" == "" (
    set WINGHOME=%~dp0
)
set WINGHOME=%WINGHOME:\=/%
if "%WINGHOME:~-1%" == "/" (
    set WINGHOME=%WINGHOME:~0,-1%
)

REM Set default Python if not given
if "%WINGDB_PYTHON%" == "" set WINGDB_PYTHON=python

REM Determine if there are extra args for Python
if "%WINGDB_PYARGS%" == "" set WINGDB_PYARGS=-u
if "%WINGDB_PYARGS%" == "-" set WINGDB_PYARGS=

REM Determine if passing a command with -c.  If so, modify it to initiate debug
set COMMAND=""
set ARGS=
set NEXT_IS_COMMAND=0
:LOOP
if "%NEXT_IS_COMMAND%" == "1" (
    set NEXT_IS_COMMAND=0
    set ARG=%~1
    set ARG=!ARG:"=\\"!
    set COMMAND="import sys; sys.path.append('''%WINGHOME%'''); import wingdbstub; del sys; !ARG!"
    set ARGS=%ARGS% !COMMAND!
) else if "%~1" == "-c" (
    set ARGS=%ARGS% %~1
    set NEXT_IS_COMMAND=1
) else (
    set ARGS=%ARGS% %1
)
shift
if not "%~1" == "" goto LOOP

REM Running code given on the command line with -c
if not %COMMAND% == "" (
    "%WINGDB_PYTHON%" %ARGS%

REM Running a Python source file
) else (
    if exist "%WINGHOME%/src/wingdb.py" (
        "%WINGDB_PYTHON%" %WINGDB_PYARGS% "%WINGHOME%/src/wingdb.py" %*
    ) else (
        "%WINGDB_PYTHON%" %WINGDB_PYARGS% "%WINGHOME%/bin/wingdb.py" %*
    )
)
